@@ -6,7 +6,7 @@ import os
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(BASE_DIR)
 sys.path.append(os.path.join(BASE_DIR, '../utils'))
-import utils1 as tf_util 
+import deep_density_estimation.utils1 as tf_util 
 
 class model_1():
     def __init__(self, batch_size, num_point):
